@@ -3,7 +3,7 @@ use strict; use warnings;
 package Net::OAuth2Server::Request::Resource;
 use parent 'Net::OAuth2Server::Request';
 
-sub allowed_methods       { qw( GET HEAD POST ) }
+sub allowed_methods       { $_[0]->method } # accept whatever the method is
 sub accepted_auth         { 'Bearer' }
 sub required_parameters   { 'access_token' }
 sub confidential_parameters { 'access_token' }
@@ -15,4 +15,4 @@ sub get_grant {
 		or ( $self->error || $self->set_error_invalid_token, return );
 }
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
